**Example 1: 示例**



Input: 

```
tccli cwp DescribeScanTaskStatus --cli-unfold-argument  \
    --ModuleType Malware
```

Output: 
```
{
    "Response": {
        "RequestId": "f1dd9f5e-4ac0-48a7-9410-c86d24656d9a",
        "State": {
            "Scanning": "",
            "Ok": "",
            "Stop": "",
            "Fail": ""
        }
    }
}
```

